@@ -230,6 +230,7 @@ setMethod("$", "Hub",
     switch(name,
      "tags"=unname(.collapse_as_string(x, .tags)),
      "rdataclass"=unname(.collapse_as_string(x, .rdataclass)),
+     "rdatapath"=unname(.collapse_as_string(x, .rdatapath)),
      "sourceurl"=unname(.collapse_as_string(x, .sourceurl)),
      "sourcetype"=unname(.collapse_as_string(x, .sourcetype)), 
      .resource_column(x, name))    ## try to get it from main resources table
@@ -394,13 +395,13 @@ setMethod("c", "Hub",
     cat(.pprintf1("dataprovider", rsrc[["dataprovider"]]))
     cat(.pprintf1("species", rsrc[["species"]]))
     cat(.pprintf1("rdataclass", rsrc[["rdataclass"]]))
+    cat(.pprintf1("rdatadateadded", rsrc[["rdatadateadded"]]))
     cat(.pprintf1("title", rsrc[["title"]]))
     cat(.pprintf1("description", rsrc[["description"]]))
     cat(.pprintf1("taxonomyid", rsrc[["taxonomyid"]]))
     cat(.pprintf1("genome", rsrc[["genome"]]))
     cat(.pprintf1("sourcetype", rsrc[["sourcetype"]]))
     cat(.pprintf1("sourceurl", rsrc[["sourceurl"]]))
-    cat(.pprintf1("sourcelastmodifieddate", date))
     cat(.pprintf1("sourcesize", size))
     cat(.pprintf0("# $tags: %s", rsrc[["tags"]]), "\n")
     cat(.pprintf0("# retrieve record with 'object[[\"%s\"]]'",
