@@ -75,6 +75,7 @@
     ## For this reason, the devel code loads OrgDbs with the release version
     ## e.g.,
     ##   ifelse(isDevel(), biocversion - 0.1, biocversion)
+    ##
     ## NOTE: Because OrgDbs are valid for a full devel cycle they are
     ##       not filtered by snapshotDate(); the OrgDbs are valid for all
     ##       snapshotDates for a given biocVersion() 
@@ -101,6 +102,11 @@
     allIds
 }
 
+## FIXME: On one hand it's convenient to have helpers for each of these fields.
+##        Yet the main (only?) use case is probably mcols() and show() in
+##        which case we want all of these and it's inefficient to search
+##        the same table multiple times for the different fields. 
+
 ## helper to retrieve tags
 .tags <- function(x) {
     query <- sprintf(
@@ -119,6 +125,15 @@
     .db_query(dbfile(x), query)
 }
 
+## helper for extracting rdatapath 
+.rdatapath <- function(x) {
+    query <- sprintf(
+        'SELECT DISTINCT rdatapath, resource_id AS id FROM rdatapaths
+         WHERE resource_id IN (%s)',
+        .id_as_single_string(x))
+    .db_query(dbfile(x), query)
+}
+
 ## helper for extracting sourceUrls
 .sourceurl <- function(x) {
     query <- sprintf(
@@ -147,7 +162,8 @@
 
 .sourcelastmodifieddate <- function(x) {
     query <- sprintf(
-        'SELECT DISTINCT sourcelastmodifieddate, resource_id AS id FROM input_sources
+        'SELECT DISTINCT sourcelastmodifieddate, resource_id AS id 
+         FROM input_sources
          WHERE resource_id IN (%s)',
         .id_as_single_string(x))
     .db_query(dbfile(x), query)
@@ -188,6 +204,7 @@
     tbl <- .query_as_data.frame(x, query)
     tbl[["tags"]] <- I(.collapse_as_list(x, .tags))
     tbl[["rdataclass"]] <- .collapse_as_string(x, .rdataclass)
+    tbl[["rdatapath"]] <- .collapse_as_string(x, .rdatapath)
     tbl[["sourceurl"]] <- .collapse_as_string(x, .sourceurl)
     tbl[["sourcetype"]] <- .collapse_as_string(x, .sourcetype)
     tbl
